# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.37
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from galv.paths.column_types_.post import ColumnTypesCreate
from galv.paths.column_types_.get import ColumnTypesList
from galv.paths.column_types_id_.patch import ColumnTypesPartialUpdate
from galv.paths.column_types_id_.get import ColumnTypesRetrieve


class ColumnTypesApi(
    ColumnTypesCreate,
    ColumnTypesList,
    ColumnTypesPartialUpdate,
    ColumnTypesRetrieve,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
