# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.37
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from galv.paths.files_id_applicable_mappings_.get import FilesApplicableMappingsRetrieve
from galv.paths.files_id_extra_metadata_.get import FilesExtraMetadataRetrieve
from galv.paths.files_.get import FilesList
from galv.paths.files_id_.patch import FilesPartialUpdate
from galv.paths.files_id_png_.get import FilesPngRetrieve
from galv.paths.files_id_reimport_.get import FilesReimportRetrieve
from galv.paths.files_id_.get import FilesRetrieve
from galv.paths.files_id_summary_.get import FilesSummaryRetrieve


class FilesApi(
    FilesApplicableMappingsRetrieve,
    FilesExtraMetadataRetrieve,
    FilesList,
    FilesPartialUpdate,
    FilesPngRetrieve,
    FilesReimportRetrieve,
    FilesRetrieve,
    FilesSummaryRetrieve,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
