# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.37
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from galv.paths.cycler_tests_.post import CyclerTestsCreate
from galv.paths.cycler_tests_id_.delete import CyclerTestsDestroy
from galv.paths.cycler_tests_.get import CyclerTestsList
from galv.paths.cycler_tests_id_.patch import CyclerTestsPartialUpdate
from galv.paths.cycler_tests_id_.get import CyclerTestsRetrieve


class CyclerTestsApi(
    CyclerTestsCreate,
    CyclerTestsDestroy,
    CyclerTestsList,
    CyclerTestsPartialUpdate,
    CyclerTestsRetrieve,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
