# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.37
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from galv.paths.monitored_paths_.post import MonitoredPathsCreate
from galv.paths.monitored_paths_id_.delete import MonitoredPathsDestroy
from galv.paths.monitored_paths_.get import MonitoredPathsList
from galv.paths.monitored_paths_id_.patch import MonitoredPathsPartialUpdate
from galv.paths.monitored_paths_id_.get import MonitoredPathsRetrieve


class MonitoredPathsApi(
    MonitoredPathsCreate,
    MonitoredPathsDestroy,
    MonitoredPathsList,
    MonitoredPathsPartialUpdate,
    MonitoredPathsRetrieve,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
