# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.37
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from galv.paths.column_mappings_.post import ColumnMappingsCreate
from galv.paths.column_mappings_id_.delete import ColumnMappingsDestroy
from galv.paths.column_mappings_.get import ColumnMappingsList
from galv.paths.column_mappings_id_.patch import ColumnMappingsPartialUpdate
from galv.paths.column_mappings_id_.get import ColumnMappingsRetrieve


class ColumnMappingsApi(
    ColumnMappingsCreate,
    ColumnMappingsDestroy,
    ColumnMappingsList,
    ColumnMappingsPartialUpdate,
    ColumnMappingsRetrieve,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
