# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from galv.paths.teams_ import Api

from galv.paths import PathValues

path = PathValues.TEAMS_