# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.37
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from galv.paths.equipment_families_.post import EquipmentFamiliesCreate
from galv.paths.equipment_families_id_.delete import EquipmentFamiliesDestroy
from galv.paths.equipment_families_.get import EquipmentFamiliesList
from galv.paths.equipment_families_id_.patch import EquipmentFamiliesPartialUpdate
from galv.paths.equipment_families_id_.get import EquipmentFamiliesRetrieve


class EquipmentFamiliesApi(
    EquipmentFamiliesCreate,
    EquipmentFamiliesDestroy,
    EquipmentFamiliesList,
    EquipmentFamiliesPartialUpdate,
    EquipmentFamiliesRetrieve,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
