# coding: utf-8

# flake8: noqa

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.37
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

__version__ = "2.1.37"

# import ApiClient
from galv.api_client import ApiClient

# import Configuration
from galv.configuration import Configuration

# import exceptions
from galv.exceptions import OpenApiException
from galv.exceptions import ApiAttributeError
from galv.exceptions import ApiTypeError
from galv.exceptions import ApiValueError
from galv.exceptions import ApiKeyError
from galv.exceptions import ApiException
