# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from galv.apis.path_to_api import path_to_api

import enum


class PathValues(str, enum.Enum):
    ACCESS_LEVELS_ = "/access_levels/"
    ACTIVATE_ = "/activate/"
    ADDITIONAL_STORAGE_ = "/additional_storage/"
    ADDITIONAL_STORAGE_ID_ = "/additional_storage/{id}/"
    ARBITRARY_FILES_ = "/arbitrary_files/"
    ARBITRARY_FILES_ID_ = "/arbitrary_files/{id}/"
    ARBITRARY_FILES_ID_FILE_ = "/arbitrary_files/{id}/file/"
    CELL_CHEMISTRIES_ = "/cell_chemistries/"
    CELL_FAMILIES_ = "/cell_families/"
    CELL_FAMILIES_ID_ = "/cell_families/{id}/"
    CELL_FORM_FACTORS_ = "/cell_form_factors/"
    CELL_MANUFACTURERS_ = "/cell_manufacturers/"
    CELL_MODELS_ = "/cell_models/"
    CELLS_ = "/cells/"
    CELLS_ID_ = "/cells/{id}/"
    CELLS_ID_RDF_ = "/cells/{id}/rdf/"
    COLUMN_MAPPINGS_ = "/column_mappings/"
    COLUMN_MAPPINGS_ID_ = "/column_mappings/{id}/"
    COLUMN_TYPES_ = "/column_types/"
    COLUMN_TYPES_ID_ = "/column_types/{id}/"
    CREATE_TOKEN_ = "/create_token/"
    CYCLER_TESTS_ = "/cycler_tests/"
    CYCLER_TESTS_ID_ = "/cycler_tests/{id}/"
    EQUIPMENT_ = "/equipment/"
    EQUIPMENT_ID_ = "/equipment/{id}/"
    EQUIPMENT_FAMILIES_ = "/equipment_families/"
    EQUIPMENT_FAMILIES_ID_ = "/equipment_families/{id}/"
    EQUIPMENT_MANUFACTURERS_ = "/equipment_manufacturers/"
    EQUIPMENT_MODELS_ = "/equipment_models/"
    EQUIPMENT_TYPES_ = "/equipment_types/"
    EXPERIMENTS_ = "/experiments/"
    EXPERIMENTS_ID_ = "/experiments/{id}/"
    FILES_ = "/files/"
    FILES_ID_ = "/files/{id}/"
    FILES_ID_APPLICABLE_MAPPINGS_ = "/files/{id}/applicable_mappings/"
    FILES_ID_EXTRA_METADATA_ = "/files/{id}/extra_metadata/"
    FILES_ID_PNG_ = "/files/{id}/png/"
    FILES_ID_REIMPORT_ = "/files/{id}/reimport/"
    FILES_ID_SUMMARY_ = "/files/{id}/summary/"
    GALV_STORAGE_ = "/galv_storage/"
    GALV_STORAGE_ID_ = "/galv_storage/{id}/"
    HARVEST_ERRORS_ = "/harvest_errors/"
    HARVEST_ERRORS_ID_ = "/harvest_errors/{id}/"
    HARVESTERS_ = "/harvesters/"
    HARVESTERS_ID_ = "/harvesters/{id}/"
    LABS_ = "/labs/"
    LABS_ID_ = "/labs/{id}/"
    LOGIN_ = "/login/"
    MONITORED_PATHS_ = "/monitored_paths/"
    MONITORED_PATHS_ID_ = "/monitored_paths/{id}/"
    PARQUET_PARTITIONS_ = "/parquet_partitions/"
    PARQUET_PARTITIONS_ID_ = "/parquet_partitions/{id}/"
    PARQUET_PARTITIONS_ID_FILE_ = "/parquet_partitions/{id}/file/"
    SCHEDULE_FAMILIES_ = "/schedule_families/"
    SCHEDULE_FAMILIES_ID_ = "/schedule_families/{id}/"
    SCHEDULE_IDENTIFIERS_ = "/schedule_identifiers/"
    SCHEDULES_ = "/schedules/"
    SCHEDULES_ID_ = "/schedules/{id}/"
    SCHEMA_VALIDATIONS_ = "/schema_validations/"
    SCHEMA_VALIDATIONS_ID_ = "/schema_validations/{id}/"
    TEAMS_ = "/teams/"
    TEAMS_ID_ = "/teams/{id}/"
    TOKENS_ = "/tokens/"
    TOKENS_ID_ = "/tokens/{id}/"
    UNITS_ = "/units/"
    UNITS_ID_ = "/units/{id}/"
    USERS_ = "/users/"
    USERS_ID_ = "/users/{id}/"
    VALIDATION_SCHEMAS_ = "/validation_schemas/"
    VALIDATION_SCHEMAS_ID_ = "/validation_schemas/{id}/"
    VALIDATION_SCHEMAS_KEYS_ = "/validation_schemas/keys/"
